package com.m2pool.pool.utils;

import com.m2pool.common.core.utils.StringUtils;
import com.m2pool.pool.enums.PoolProfitScale;

import java.math.BigDecimal;

/**
 * @Description 算力转换
 * @Date 2024/6/13 10:54
 * @Author dy
 */
public class PowerUnitUtils {

    /**
     * 算力数值转换 1000转 1KH/s 1000*1000转1MH/s 1000*1000*1000转1GH/s 1000*1000*1000*10转10TH/s
     * @param value
     * @return
     */
    public static String powerFormat(BigDecimal value, String coin){

        if(StringUtils.isNull(value)){
            return "0 H/s";
        }

        int scale = PoolProfitScale.getScaleByCoin(coin);
        //ps BigDecimal最大上限少于1000*1000*1000*1000*10 所以需要中间值 gValue
        BigDecimal gValue = value.divide(BigDecimal.valueOf(1000000000), scale, BigDecimal.ROUND_HALF_UP);
        if (gValue.compareTo(BigDecimal.valueOf(1000*1000*1000)) >= 0){
            //1000*1000*1000G以上 转换为E
            return gValue.divide(BigDecimal.valueOf(1000000000),scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " EH/s";
        }
        else if (gValue.compareTo(BigDecimal.valueOf(1000*1000)) >= 0){
            //1000*1000G以上 1000*1000*1000G以下 转换为P
            return gValue.divide(BigDecimal.valueOf(1000000),scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " PH/s";
        }
        else if (gValue.compareTo(BigDecimal.valueOf(10000)) >= 0){
            //10000G 以上 1000*1000G一下 则转为T 即10T以上才转换
            return gValue.divide(BigDecimal.valueOf(1000),scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " TH/s";
        }
        else if (value.compareTo(BigDecimal.valueOf(1000*1000*1000)) >= 0){
            //1G 1G以上 10T以下 转换为G
            return gValue.setScale(scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " GH/s";
        }
        else if (value.compareTo(BigDecimal.valueOf(1000*1000)) >= 0){
            //1M 1M以上 1G一下则转换为M
            return value.divide(BigDecimal.valueOf(1000*1000), scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " MH/s";
        }
        else if (value.compareTo(BigDecimal.valueOf(1000)) >= 0){
            //1K 1K以上 1M一下则转换为K
            return value.divide(BigDecimal.valueOf(1000), scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " KH/s";
        }
        else {
            return value.setScale(scale,BigDecimal.ROUND_HALF_UP).toEngineeringString() + " H/s";
        }
    }

    /**
     * 难度数值转换 1000转 1K 1000*1000转1M 1000*1000*1000转1G
     * @param value
     * @return
     */
    public static String difficultyFormat(BigDecimal value){

        if(StringUtils.isNull(value)){
            return "0";
        }
        if (value.compareTo(BigDecimal.valueOf(1000*1000*1000)) >= 0){
            return value.divide(BigDecimal.valueOf(1000*1000*1000),2,BigDecimal.ROUND_HALF_UP).toEngineeringString()+"G";
        }else if (value.compareTo(BigDecimal.valueOf(1000*1000)) >= 0){
            return value.divide(BigDecimal.valueOf(1000*1000),2,BigDecimal.ROUND_HALF_UP).toEngineeringString()+"M";
        }else if (value.compareTo(BigDecimal.valueOf(1000)) >= 0){
            return value.divide(BigDecimal.valueOf(1000),2,BigDecimal.ROUND_HALF_UP).toEngineeringString()+"K";
        }else {
            return value.setScale(2,BigDecimal.ROUND_HALF_UP).toEngineeringString();
        }
    }
}
