package com.m2pool.pool.task;

import com.m2pool.common.core.text.Convert;
import com.m2pool.common.core.utils.DateUtils;
import com.m2pool.common.core.utils.StringUtils;
import com.m2pool.common.redis.service.RedisService;
import com.m2pool.pool.context.BlockDataContext;
import com.m2pool.pool.dto.*;
import com.m2pool.pool.entity.PoolPower;
import com.m2pool.pool.enums.PoolCalParamConfig;
import com.m2pool.pool.enums.PoolUnits;
import com.m2pool.pool.enums.Pools;
import com.m2pool.pool.mapper.PoolMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @Description 矿池、矿机定时任务 主要处理算力数据和幸运值计算
 * 新增币种则新增定时任务 注意岔开处理时间
 * @Date 2024/6/14 14:03
 * @Author dy
 */
@Configuration
@EnableScheduling
public class DataTask {

    @Autowired
    private PoolMapper poolMapper;

    @Autowired
    private RedisService redisService;

    @Autowired
    private BlockDataContext blockDataContext;

    private static final Logger log = LoggerFactory.getLogger(DataTask.class);


    @Scheduled(cron = "20 1,3,10,31,33,40 * * * ?")
    public void NEXA30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("nexa 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.NEXA.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.NEXA.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){
                List<MinerDataDto> offlineList = new ArrayList<>();
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.NEXA.getFac());
                    }
                    if("offline".equals(e.getState())){
                        offlineList.add(e);
                    }
                });
                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.NEXA.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "nexa小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "nexa小时数据存入数据失败");
                }

                if(offlineList.size() >0){
                    CompletableFuture.runAsync(()->{

                        //根据挖矿账户分组、统计离线矿机名单、离线矿机数

                        //对比redis中该挖矿账户上一次离线矿机数
                            //有redis数据 需要判断 上一次离线矿机数<本次矿机离线数 才执行通知 否则跳过
                            //无redis数据 说明是第一次 执行通知
                    });

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("nexa 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.NEXA.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.NEXA.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.NEXA.getFac());
                                }
                            });
                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.NEXA.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "nexa30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "nexa30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "0 1,3,5 0 * * ?")
    public void NEXADailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.NEXA.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.NEXA.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.NEXA.getFac());
                    }
                });
                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.NEXA.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"nexa每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"nexa每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("nexa 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.NEXA.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.NEXA.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.NEXA.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.NEXA.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.NEXA.getName() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.NEXA.getPoolTable() + "_24h", poolPower);
                            System.out.println("延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "50 0,1,30,31 * * * ?")
    public void NEXAUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = poolMapper.getPoolTodayTotalPower("nexa", nowStr);
        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("nexa", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
        });

        if(map.size() >0){
            redisService.deleteObject("NEXAUserPowerRatio");
            redisService.setCacheMap("NEXAUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "30 2,5 0/12 * * ?")
    public void NEXALuckyDataToDB(){
        log.info("nexa幸运值---延时任务开始");
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        //幸运值 = 矿池实际报块/矿池理论报块
        //矿池实际报块 = 数据库查询表名为币名_pool_blkstats
        //矿池理论报块 =  (矿池过去N段时间的平均算力 / 全网过去N段时间平均算力) * 全网过去N段时间实际报块
        Date start3d = DateUtils.addDays(end,-3);
        Date start7d = DateUtils.addDays(end,-7);
        Date start30d = DateUtils.addDays(end,-30);
        Date start90d = DateUtils.addDays(end,-90);


        //获取全网实际90天内的报块数(v2)
        List<BlockInfoDto> blockPerDays = poolMapper.selectNetBlock("nexa_net_block");
        boolean useAggregated = blockPerDays.size() >= 3;
        //获取3天内全网的实际报块数
        BlockTimeAndNumberDto blockData = blockDataContext.getBlockData("nexa",start3d, end,blockPerDays, useAggregated);
        //3天矿池理论报块数
        BigDecimal throreticalBlocks = getTheoreticalBlocks("nexa",PoolUnits.NEXA.gethRate(),start3d, end, blockData);
        //3天矿池实际报块数
        int actualBlocks = poolMapper.selectPoolBlock(3);
        //3天幸运值
        dto.setLuck3d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //7天幸运值
        useAggregated = blockPerDays.size() >= 7;
     
        blockData = blockDataContext.getBlockData("nexa",start7d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("nexa",PoolUnits.NEXA.gethRate(),start7d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(7);
        dto.setLuck7d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //30天幸运值
        useAggregated = blockPerDays.size() >= 30;
     
        blockData = blockDataContext.getBlockData("nexa",start30d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("nexa",PoolUnits.NEXA.gethRate(),start30d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(30);
        dto.setLuck30d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());


        //90天幸运值
        useAggregated = blockPerDays.size() >= 90;
     
        blockData = blockDataContext.getBlockData("nexa",start90d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("nexa",PoolUnits.NEXA.gethRate(),start90d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(90);
        dto.setLuck90d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());


        redisService.deleteObject("NEXALuck");
        redisService.setCacheObject("NEXALuck",dto);
        log.info("nexa幸运值入库完成");
    }


    /**
     * 币种 理论出块数
     * @param coin 币种名
     * @param start 开始时间
     * @param end 结束时间（当前时间）
     * @param blockData
     * @return
     */
    public BigDecimal getTheoreticalBlocks(String coin,int hRate,Date start,Date end,BlockTimeAndNumberDto blockData){

        //得到每一个小时定时任务存储到数据库的全网算力
        List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower(coin);
        if(netPowerList.isEmpty()){
            return BigDecimal.ZERO;
        }
        //得时间段到矿池的算力
        List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower(coin);
        //A:矿池N天总算力
        //计算矿池每日实际应出块数  block中算力单位是H/s
        BigDecimal pPow3d = poolPowerList.stream()
                .filter(e -> (e.getPDate().before(end)))
                .filter(e -> (e.getPDate().after(start) || e.getPDate().equals(start)))
                .map(DateBigDecimalDto::getValue).reduce(BigDecimal.ZERO, BigDecimal::add)
                .multiply(BigDecimal.valueOf(hRate));
        //作为A的除数，得到N天内的矿池平均算力
        long pDay3d = poolPowerList.stream()
                .filter(e -> (e.getPDate().before(end)))
                .filter(e -> (e.getPDate().after(start) || e.getPDate().equals(start))).count();

        //B:N天全网算力
        BigDecimal nPow3d = netPowerList.stream()
                .filter(e -> (e.getPDate().before(end)))
                .filter(e -> (e.getPDate().after(start) || e.getPDate().equals(start)))
                .map(DateBigDecimalDto::getValue).reduce(BigDecimal.ZERO, BigDecimal::add);

        //作为B的除数，得到3天内的全网平均算力
        long nDay3d = netPowerList.stream()
                .filter(e -> (e.getPDate().before(end)))
                .filter(e -> (e.getPDate().after(start) || e.getPDate().equals(start))).count();

        if(pDay3d == 0 || nDay3d == 0){
            return BigDecimal.ZERO;
        }

        return pPow3d
                .divide(BigDecimal.valueOf(pDay3d),8, RoundingMode.HALF_UP)
                .divide(nPow3d,8, RoundingMode.HALF_UP)
                .multiply(BigDecimal.valueOf(nDay3d))
                .multiply(BigDecimal.valueOf(blockData.getHeight()))
                .multiply(blockData.getDateLength())
                .setScale(8, RoundingMode.HALF_UP);

    }

    @Scheduled(cron = "11 1,3,11,31,33,41 * * * ?")
    public void GRS30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("grs 30分钟定时任务执行时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.GRS.getMhs() + "30m", nowStr);

        System.out.println("二级表当前时间点数据条数："+count);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.GRS.getMhs()+"_realv2",nowStr);

            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.GRS.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.GRS.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("GRS user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "grs小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "grs小时数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("grs 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.GRS.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.GRS.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){


                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.GRS.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.GRS.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "grs30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "grs数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "1 1,3,5 0 * * ?")
    public void GRSDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.GRS.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.GRS.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.GRS.getFac());
                    }
                });
                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.GRS.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"grs每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"grs每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("grs 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.GRS.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.GRS.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.GRS.getFac());
                                }
                            });

                            newList = filterList(newList,now);


                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.GRS.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.GRS.getName() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.GRS.getPoolTable() + "_24h", poolPower);
                            System.out.println("延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "51 0,1,30,31 * * * ?")
    public void GRSUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = Convert.toBigDecimal( poolMapper.getPoolTodayTotalPower("grs", nowStr),BigDecimal.ONE);

        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("grs", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            if(StringUtils.isNull(e.getMhs())){
                map.put(e.getUser(),BigDecimal.ZERO.setScale(8).stripTrailingZeros());
            }else {
                map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
            }
        });

        if(map.size() >0){
            redisService.deleteObject("GRSUserPowerRatio");
            redisService.setCacheMap("GRSUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "31 2,5 0/12 * * ?")
    public void GRSLuckyDataToDB(){
        log.info("GRS幸运值---定时任务开始");
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        //幸运值 = 矿池实际报块/矿池理论报块
        //矿池实际报块 = 数据库查询表名为币名_pool_blkstats
        //矿池理论报块 =  (矿池过去N段时间的平均算力 / 全网过去N段时间平均算力) * 全网过去N段时间实际报块
        Date start3d = DateUtils.addDays(end,-3);
        Date start7d = DateUtils.addDays(end,-7);
        Date start30d = DateUtils.addDays(end,-30);
        Date start90d = DateUtils.addDays(end,-90);


        //获取全网实际90天内的报块数(v2)
        List<BlockInfoDto> blockPerDays = poolMapper.selectNetBlock("grs_net_block");
        boolean useAggregated = blockPerDays.size() >= 3;
        //获取3天内全网的实际报块数
        BlockTimeAndNumberDto blockData = blockDataContext.getBlockData("grs",start3d, end,blockPerDays, useAggregated);
        //3天矿池理论报块数
        BigDecimal throreticalBlocks= getTheoreticalBlocks("grs",PoolUnits.GRS.gethRate(),start3d, end, blockData);
        //3天矿池实际报块数
        int actualBlocks = poolMapper.selectPoolBlock(3);
        //3天幸运值
        dto.setLuck3d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //7天幸运值
        useAggregated = blockPerDays.size() >= 7;
     
        blockData = blockDataContext.getBlockData("grs",start7d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("grs",PoolUnits.GRS.gethRate(),start7d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(7);
        dto.setLuck7d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //30天幸运值
        useAggregated = blockPerDays.size() >= 30;
     
        blockData = blockDataContext.getBlockData("grs",start30d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("grs",PoolUnits.GRS.gethRate(),start30d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(30);
        dto.setLuck30d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());


        //90天幸运值
        useAggregated = blockPerDays.size() >= 90;
        blockData = blockDataContext.getBlockData("grs",start90d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("grs",PoolUnits.GRS.gethRate(),start90d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(90);
        dto.setLuck90d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());



        redisService.deleteObject("GRSLuck");
        redisService.setCacheObject("GRSLuck",dto);
        log.info("grs幸运值入库完成");
    }

    @Scheduled(cron = "12 1,3,12,31,33,42 * * * ?")
    public void MONA30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("mona 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.MONA.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.MONA.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.MONA.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.MONA.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("MONA user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "mona小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "mona小时数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("mona 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.MONA.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.MONA.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.MONA.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.MONA.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "mona30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "mona30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "2 1,3,5 0 * * ?")
    public void MONADailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.MONA.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.MONA.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.MONA.getFac());
                    }
                });

                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.MONA.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    System.out.println("date:"+date);
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"mona每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"mona每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("mona 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.MONA.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.MONA.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.MONA.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.MONA.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.MONA.getName() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.MONA.getPoolTable() + "_24h", poolPower);
                            System.out.println("延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "52 0,1,30,31 * * * ?")
    public void MONAUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = Convert.toBigDecimal( poolMapper.getPoolTodayTotalPower("mona", nowStr),BigDecimal.ONE);

        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("mona", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            if(StringUtils.isNull(e.getMhs())){
                map.put(e.getUser(),BigDecimal.ZERO.setScale(8).stripTrailingZeros());
            }else {
                map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
            }
        });

        if(map.size() >0){
            redisService.deleteObject("MONAUserPowerRatio");
            redisService.setCacheMap("MONAUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "32 2,5 0/12 * * ?")
    public void MONALuckyDataToDB(){
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        //幸运值 = 矿池实际报块/矿池理论报块
        //矿池实际报块 = 数据库查询表名为币名_pool_blkstats
        //矿池理论报块 =  (矿池过去N段时间的平均算力 / 全网过去N段时间平均算力) * 全网过去N段时间实际报块
        Date start3d = DateUtils.addDays(end,-3);
        Date start7d = DateUtils.addDays(end,-7);
        Date start30d = DateUtils.addDays(end,-30);
        Date start90d = DateUtils.addDays(end,-90);


        //获取全网实际90天内的报块数(v2)
        List<BlockInfoDto> blockPerDays = poolMapper.selectNetBlock("mona_net_block");
     

        boolean useAggregated = blockPerDays.size() >= 3;
        //获取3天内全网的实际报块数
     
        BlockTimeAndNumberDto blockData = blockDataContext.getBlockData("mona",start3d, end,blockPerDays, useAggregated);
        //3天矿池理论报块数
        BigDecimal throreticalBlocks= getTheoreticalBlocks("mona",PoolUnits.MONA.gethRate(),start3d, end, blockData);

        //3天矿池实际报块数
        int actualBlocks = poolMapper.selectPoolBlock(3);
        //3天幸运值
        dto.setLuck3d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //7天幸运值
        useAggregated = blockPerDays.size() >= 7;
     
        blockData = blockDataContext.getBlockData("mona",start7d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("mona",PoolUnits.MONA.gethRate(),start7d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(7);
        dto.setLuck7d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //30天幸运值
        useAggregated = blockPerDays.size() >= 30;
     
        blockData = blockDataContext.getBlockData("mona",start30d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("nexa",PoolUnits.MONA.gethRate(),start30d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(30);
        dto.setLuck30d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());


        //90天幸运值
        useAggregated = blockPerDays.size() >= 90;
     
        blockData = blockDataContext.getBlockData("mona",start90d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("mona",PoolUnits.MONA.gethRate(),start90d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(90);
        dto.setLuck90d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        redisService.deleteObject("MONALuck");
        redisService.setCacheObject("MONALuck",dto);
    }

    @Scheduled(cron = "14 1,3,9,31,33,39 * * * ?")
    public void DGBO30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("DGBO 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBO.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.DGBO.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBO.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBO.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("DGBO 构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("DGBO user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "DGBO 30m数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "DGBO 30m数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("DGBO 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBO.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.DGBO.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBO.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBO.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 DGBO构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 DGBO user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "DGBO 30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "DGBO 30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "4 1,3,5 0 * * ?")
    public void DGBODailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBO.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.DGBO.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBO.getFac());
                    }
                });

                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBO.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    System.out.println("date:"+date);
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"DGBO 每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"DGBO 每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("DGBO 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBO.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.DGBO.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBO.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBO.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBO.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.DGBO.getPoolTable() + "_24h", poolPower);
                            System.out.println("DGBO延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "54 0,1,30,31 * * * ?")
    public void DGBOUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = Convert.toBigDecimal( poolMapper.getPoolTodayTotalPower("dgbo", nowStr),BigDecimal.ONE);

        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("dgbo", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            if(StringUtils.isNull(e.getMhs())){
                map.put(e.getUser(),BigDecimal.ZERO.setScale(8).stripTrailingZeros());
            }else {
                map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
            }
        });

        if(map.size() >0){
            redisService.deleteObject("DGBOUserPowerRatio");
            redisService.setCacheMap("DGBOUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "34 2,5 0/12 * * ?")
    public void DGBOLuckyDataToDB(){
        int time = 0;
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        do {
            //幸运值
            // N天应出块数量 = N天矿池平均算力/ N天全网平均算力 * 币种每日出块数 * N天  取同一时间点的矿池算力/全网算力
            // 币种每日出块数 = 720        数值来源: 每日分钟数(24*60) / 出一个块需要的时间(根据具体币种 nexa是2分钟)
            // N天实际出块量 数据库查询N天实际出块量
            // N天幸运值 = N天实际出块量 / N天应出块量 * 100  结果即百分比数字%
            /** 全网每日出块数 */
            BigDecimal dgboCount = PoolCalParamConfig.DGBO.getCount();

            //计算矿池每日实际应出块数  block中算力单位是H/s
            int hRate = PoolUnits.DGBO.gethRate();
            //先把矿池算力单位转换为H/s 再除以全网算力 得到比值 再乘以每日全网出块数 得到矿池每日应出块数
            List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower("dgbo");
            if(netPowerList.size() < 1){
                continue;
            }

            List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower("dgbo");

            //拿报块list 筛选实际出块数
            //List<BlockInfoDto> list = poolMapper.getNEXABlockInfoList();
            List<BlockInfoDto> list = poolMapper.getDGBODOBlockInfoList();

            if (list.size() < 1){
                continue;
            }

            //第一条报块数据的时间
            Date poolStart = list.get(list.size() - 1).getDate();
            Date start3d = DateUtils.addDays(end,-3);
            Date start7d = DateUtils.addDays(end,-7);
            Date start30d = DateUtils.addDays(end,-30);
            Date start90d = DateUtils.addDays(end,-90);
            //(矿池平均/全网平均) * (全网计算平均的时间/矿池计算平均的时间) * 每日全网出块数 = 矿池每日应出块数
            long pDay3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            //矿池单位转换
            BigDecimal pPow3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            BigDecimal nPow3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay3d == 0 || nDay3d == 0){
                continue;
            }
            //计算3天 每日出块量
            BigDecimal dayChunk3d = pPow3d
                    .multiply(BigDecimal.valueOf(nDay3d * nDay3d))
                    .divide(nPow3d.multiply(BigDecimal.valueOf(pDay3d * pDay3d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(dgboCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal pPow7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal nPow7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay7d == 0 || nDay7d == 0){
                continue;
            }

            //计算7d 每日应出块量
            BigDecimal dayChunk7d = pPow7d
                    .multiply(BigDecimal.valueOf(nDay7d * nDay7d))
                    .divide(nPow7d.multiply(BigDecimal.valueOf(pDay7d * pDay7d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(dgboCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal pPow30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal nPow30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay30d == 0 || nDay30d == 0){
                continue;
            }

            //计算30d 每日应出块量
            BigDecimal dayChunk30d = pPow30d
                    .multiply(BigDecimal.valueOf(nDay30d * nDay30d))
                    .divide(nPow30d.multiply(BigDecimal.valueOf(pDay30d * pDay30d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(dgboCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal pPow90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal nPow90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay90d == 0 || nDay90d == 0){
                continue;
            }

            //计算90d 每日应出块量
            BigDecimal dayChunk90d = pPow90d
                    .multiply(BigDecimal.valueOf(nDay90d * nDay90d))
                    .divide(nPow90d.multiply(BigDecimal.valueOf(pDay90d * pDay90d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(dgboCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            //3天时间出块数
            long count3d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start3d) || e.getDate().equals(start3d)))
                    .count();
            BigDecimal chunk3d = BigDecimal.valueOf(count3d);
            //7天时间出块数
            long count7d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start7d) || e.getDate().equals(start7d)))
                    .count();
            BigDecimal chunk7d = BigDecimal.valueOf(count7d);
            //30天时间出块数
            long count30d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start30d) || e.getDate().equals(start30d)))
                    .count();
            BigDecimal chunk30d = BigDecimal.valueOf(count30d);
            //90天时间出块数
            long count90d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start90d) || e.getDate().equals(start90d)))
                    .count();
            BigDecimal chunk90d = BigDecimal.valueOf(count90d);

            if(poolStart.after(start3d)){
                System.out.println("不足3天");
                long needTime = poolStart.getTime()-start3d.getTime();
                chunk3d = chunk3d
                        .add(dayChunk3d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("3天出块量"+chunk3d);
            dto.setLuck3d(chunk3d.divide(dayChunk3d.multiply(BigDecimal.valueOf(3)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start7d)){
                System.out.println("不足7天");
                long needTime = poolStart.getTime()-start7d.getTime();
                chunk7d = chunk7d
                        .add(dayChunk7d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("7天出块量"+chunk7d);
            dto.setLuck7d(chunk7d.divide(dayChunk7d.multiply(BigDecimal.valueOf(7)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());


            if(poolStart.after(start30d)){
                System.out.println("不足30天");
                long needTime = poolStart.getTime()-start30d.getTime();
                chunk30d = chunk30d
                        .add(dayChunk30d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("30天出块量"+chunk30d);
            dto.setLuck30d(chunk30d.divide(dayChunk30d.multiply(BigDecimal.valueOf(30)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start90d)){
                System.out.println("不足90天");
                long needTime = poolStart.getTime()-start90d.getTime();
                chunk90d = chunk90d
                        .add(dayChunk90d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("90天出块量"+chunk90d);
            dto.setLuck90d(chunk90d.divide(dayChunk90d.multiply(BigDecimal.valueOf(90)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            break;
        }while (time < 4);

        redisService.deleteObject("DGBOLuck");
        redisService.setCacheObject("DGBOLuck",dto);
    }

    @Scheduled(cron = "16 1,3,8,31,33,38 * * * ?")
    public void DGBQ30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("DGBQ 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBQ.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.DGBQ.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBQ.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBQ.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("DGBQ 构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("DGBQ user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "DGBQ 30m数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "DGBQ 30m数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println(DateUtils.dateTimeNow()+"DGBQ 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBQ.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.DGBQ.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBQ.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBQ.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 DGBQ构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 DGBQ user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "DGBQ 30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "DGBO 30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "6 1,3,5 0 * * ?")
    public void DGBQDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBQ.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.DGBQ.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBQ.getFac());
                    }
                });

                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBQ.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    System.out.println("date:"+date);
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"DGBQ 每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"DGBQ 每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("DGBQ 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBQ.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.DGBQ.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBQ.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBQ.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBQ.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.DGBQ.getPoolTable() + "_24h", poolPower);
                            System.out.println("DGBQ延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "56 0,1,30,31 * * * ?")
    public void DGBQUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = Convert.toBigDecimal( poolMapper.getPoolTodayTotalPower("dgbq", nowStr),BigDecimal.ONE);

        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("dgbq", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            if(StringUtils.isNull(e.getMhs())){
                map.put(e.getUser(),BigDecimal.ZERO.setScale(8).stripTrailingZeros());
            }else {
                map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
            }
        });

        if(map.size() >0){
            redisService.deleteObject("DGBQUserPowerRatio");
            redisService.setCacheMap("DGBQUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "36 2,5 0/12 * * ?")
    public void DGBQLuckyDataToDB(){
        int time = 0;
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        do {
            //幸运值
            // N天应出块数量 = N天矿池平均算力/ N天全网平均算力 * 币种每日出块数 * N天  取同一时间点的矿池算力/全网算力
            // 币种每日出块数 = 720        数值来源: 每日分钟数(24*60) / 出一个块需要的时间(根据具体币种 nexa是2分钟)
            // N天实际出块量 数据库查询N天实际出块量
            // N天幸运值 = N天实际出块量 / N天应出块量 * 100  结果即百分比数字%
            /** 全网每日出块数 */
            BigDecimal nexaCount = PoolCalParamConfig.DGBQ.getCount();

            //计算矿池每日实际应出块数  block中算力单位是H/s
            int hRate = PoolUnits.DGBQ.gethRate();
            //先把矿池算力单位转换为H/s 再除以全网算力 得到比值 再乘以每日全网出块数 得到矿池每日应出块数
            List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower("dgbq");
            if(netPowerList.size() < 1){
                continue;
            }

            List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower("dgbq");

            //拿报块list 筛选实际出块数
            //List<BlockInfoDto> list = poolMapper.getNEXABlockInfoList();
            List<BlockInfoDto> list = poolMapper.getDgbQubitBlockInfoList();

            if (list.size() < 1){
                continue;
            }

            //第一条报块数据的时间
            Date poolStart = list.get(list.size() - 1).getDate();
            Date start3d = DateUtils.addDays(end,-3);
            Date start7d = DateUtils.addDays(end,-7);
            Date start30d = DateUtils.addDays(end,-30);
            Date start90d = DateUtils.addDays(end,-90);
            //(矿池平均/全网平均) * (全网计算平均的时间/矿池计算平均的时间) * 每日全网出块数 = 矿池每日应出块数
            long pDay3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            //矿池单位转换
            BigDecimal pPow3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            BigDecimal nPow3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay3d == 0 || nDay3d == 0){
                continue;
            }
            //计算3天 每日出块量
            BigDecimal dayChunk3d = pPow3d
                    .multiply(BigDecimal.valueOf(nDay3d * nDay3d))
                    .divide(nPow3d.multiply(BigDecimal.valueOf(pDay3d * pDay3d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal pPow7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal nPow7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay7d == 0 || nDay7d == 0){
                continue;
            }

            //计算7d 每日应出块量
            BigDecimal dayChunk7d = pPow7d
                    .multiply(BigDecimal.valueOf(nDay7d * nDay7d))
                    .divide(nPow7d.multiply(BigDecimal.valueOf(pDay7d * pDay7d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal pPow30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal nPow30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay30d == 0 || nDay30d == 0){
                continue;
            }

            //计算30d 每日应出块量
            BigDecimal dayChunk30d = pPow30d
                    .multiply(BigDecimal.valueOf(nDay30d * nDay30d))
                    .divide(nPow30d.multiply(BigDecimal.valueOf(pDay30d * pDay30d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal pPow90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal nPow90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay90d == 0 || nDay90d == 0){
                continue;
            }

            //计算90d 每日应出块量
            BigDecimal dayChunk90d = pPow90d
                    .multiply(BigDecimal.valueOf(nDay90d * nDay90d))
                    .divide(nPow90d.multiply(BigDecimal.valueOf(pDay90d * pDay90d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            //3天时间出块数
            long count3d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start3d) || e.getDate().equals(start3d)))
                    .count();
            BigDecimal chunk3d = BigDecimal.valueOf(count3d);
            //7天时间出块数
            long count7d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start7d) || e.getDate().equals(start7d)))
                    .count();
            BigDecimal chunk7d = BigDecimal.valueOf(count7d);
            //30天时间出块数
            long count30d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start30d) || e.getDate().equals(start30d)))
                    .count();
            BigDecimal chunk30d = BigDecimal.valueOf(count30d);
            //90天时间出块数
            long count90d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start90d) || e.getDate().equals(start90d)))
                    .count();
            BigDecimal chunk90d = BigDecimal.valueOf(count90d);

            if(poolStart.after(start3d)){
                System.out.println("不足3天");
                long needTime = poolStart.getTime()-start3d.getTime();
                chunk3d = chunk3d
                        .add(dayChunk3d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("3天出块量"+chunk3d);
            dto.setLuck3d(chunk3d.divide(dayChunk3d.multiply(BigDecimal.valueOf(3)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start7d)){
                System.out.println("不足7天");
                long needTime = poolStart.getTime()-start7d.getTime();
                chunk7d = chunk7d
                        .add(dayChunk7d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("7天出块量"+chunk7d);
            dto.setLuck7d(chunk7d.divide(dayChunk7d.multiply(BigDecimal.valueOf(7)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());


            if(poolStart.after(start30d)){
                System.out.println("不足30天");
                long needTime = poolStart.getTime()-start30d.getTime();
                chunk30d = chunk30d
                        .add(dayChunk30d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("30天出块量"+chunk30d);
            dto.setLuck30d(chunk30d.divide(dayChunk30d.multiply(BigDecimal.valueOf(30)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start90d)){
                System.out.println("不足90天");
                long needTime = poolStart.getTime()-start90d.getTime();
                chunk90d = chunk90d
                        .add(dayChunk90d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("90天出块量"+chunk90d);
            dto.setLuck90d(chunk90d.divide(dayChunk90d.multiply(BigDecimal.valueOf(90)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            break;
        }while (time < 4);

        redisService.deleteObject("DGBQLuck");
        redisService.setCacheObject("DGBQLuck",dto);
    }

    @Scheduled(cron = "18 1,3,7,31,33,37 * * * ?")
    public void DGBS30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("DGBS 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBS.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.DGBS.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBS.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBS.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("DGBS 构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("DGBS user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "DGBS 30m数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "DGBS 30m数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("DGBS 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBS.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.DGBS.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBS.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBS.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 DGBS构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 DGBS user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "DGBS 30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "DGBS 30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "8 1,3,5 0 * * ?")
    public void DGBSDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.DGBS.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.DGBS.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.DGBS.getFac());
                    }
                });

                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.DGBS.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    System.out.println("date:"+date);
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"DGBS 每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"DGBS 每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("DGBS 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.DGBS.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.DGBS.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.DGBS.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.DGBS.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.DGBS.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.DGBS.getPoolTable() + "_24h", poolPower);
                            System.out.println("DGBS延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "58 0,1,30,31 * * * ?")
    public void DGBSUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = Convert.toBigDecimal( poolMapper.getPoolTodayTotalPower("dgbs", nowStr),BigDecimal.ONE);

        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("dgbs", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            if(StringUtils.isNull(e.getMhs())){
                map.put(e.getUser(),BigDecimal.ZERO.setScale(8).stripTrailingZeros());
            }else {
                map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
            }
        });

        if(map.size() >0){
            redisService.deleteObject("DGBSUserPowerRatio");
            redisService.setCacheMap("DGBSUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "38 2,5 0/12 * * ?")
    public void DGBSLuckyDataToDB(){
        int time = 0;
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        do {
            //幸运值
            // N天应出块数量 = N天矿池平均算力/ N天全网平均算力 * 币种每日出块数 * N天  取同一时间点的矿池算力/全网算力
            // 币种每日出块数 = 720        数值来源: 每日分钟数(24*60) / 出一个块需要的时间(根据具体币种 nexa是2分钟)
            // N天实际出块量 数据库查询N天实际出块量
            // N天幸运值 = N天实际出块量 / N天应出块量 * 100  结果即百分比数字%
            /** 全网每日出块数 */
            BigDecimal nexaCount = PoolCalParamConfig.DGBS.getCount();

            //计算矿池每日实际应出块数  block中算力单位是H/s
            int hRate = PoolUnits.DGBS.gethRate();
            //先把矿池算力单位转换为H/s 再除以全网算力 得到比值 再乘以每日全网出块数 得到矿池每日应出块数
            List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower("dgbs");
            if(netPowerList.size() < 1){
                continue;
            }

            List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower("dgbs");

            //拿报块list 筛选实际出块数
            //List<BlockInfoDto> list = poolMapper.getNEXABlockInfoList();
            List<BlockInfoDto> list = poolMapper.getDgbSkeinBlockInfoList();

            if (list.size() < 1){
                continue;
            }

            //第一条报块数据的时间
            Date poolStart = list.get(list.size() - 1).getDate();
            Date start3d = DateUtils.addDays(end,-3);
            Date start7d = DateUtils.addDays(end,-7);
            Date start30d = DateUtils.addDays(end,-30);
            Date start90d = DateUtils.addDays(end,-90);
            //(矿池平均/全网平均) * (全网计算平均的时间/矿池计算平均的时间) * 每日全网出块数 = 矿池每日应出块数
            long pDay3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            //矿池单位转换
            BigDecimal pPow3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            BigDecimal nPow3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay3d == 0 || nDay3d == 0){
                continue;
            }
            //计算3天 每日出块量
            BigDecimal dayChunk3d = pPow3d
                    .multiply(BigDecimal.valueOf(nDay3d * nDay3d))
                    .divide(nPow3d.multiply(BigDecimal.valueOf(pDay3d * pDay3d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal pPow7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal nPow7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay7d == 0 || nDay7d == 0){
                continue;
            }

            //计算7d 每日应出块量
            BigDecimal dayChunk7d = pPow7d
                    .multiply(BigDecimal.valueOf(nDay7d * nDay7d))
                    .divide(nPow7d.multiply(BigDecimal.valueOf(pDay7d * pDay7d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal pPow30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal nPow30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay30d == 0 || nDay30d == 0){
                continue;
            }

            //计算30d 每日应出块量
            BigDecimal dayChunk30d = pPow30d
                    .multiply(BigDecimal.valueOf(nDay30d * nDay30d))
                    .divide(nPow30d.multiply(BigDecimal.valueOf(pDay30d * pDay30d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal pPow90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal nPow90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay90d == 0 || nDay90d == 0){
                continue;
            }

            //计算90d 每日应出块量
            BigDecimal dayChunk90d = pPow90d
                    .multiply(BigDecimal.valueOf(nDay90d * nDay90d))
                    .divide(nPow90d.multiply(BigDecimal.valueOf(pDay90d * pDay90d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            //3天时间出块数
            long count3d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start3d) || e.getDate().equals(start3d)))
                    .count();
            BigDecimal chunk3d = BigDecimal.valueOf(count3d);
            //7天时间出块数
            long count7d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start7d) || e.getDate().equals(start7d)))
                    .count();
            BigDecimal chunk7d = BigDecimal.valueOf(count7d);
            //30天时间出块数
            long count30d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start30d) || e.getDate().equals(start30d)))
                    .count();
            BigDecimal chunk30d = BigDecimal.valueOf(count30d);
            //90天时间出块数
            long count90d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start90d) || e.getDate().equals(start90d)))
                    .count();
            BigDecimal chunk90d = BigDecimal.valueOf(count90d);

            if(poolStart.after(start3d)){
                System.out.println("不足3天");
                long needTime = poolStart.getTime()-start3d.getTime();
                chunk3d = chunk3d
                        .add(dayChunk3d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("3天出块量"+chunk3d);
            dto.setLuck3d(chunk3d.divide(dayChunk3d.multiply(BigDecimal.valueOf(3)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start7d)){
                System.out.println("不足7天");
                long needTime = poolStart.getTime()-start7d.getTime();
                chunk7d = chunk7d
                        .add(dayChunk7d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("7天出块量"+chunk7d);
            dto.setLuck7d(chunk7d.divide(dayChunk7d.multiply(BigDecimal.valueOf(7)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());


            if(poolStart.after(start30d)){
                System.out.println("不足30天");
                long needTime = poolStart.getTime()-start30d.getTime();
                chunk30d = chunk30d
                        .add(dayChunk30d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("30天出块量"+chunk30d);
            dto.setLuck30d(chunk30d.divide(dayChunk30d.multiply(BigDecimal.valueOf(30)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start90d)){
                System.out.println("不足90天");
                long needTime = poolStart.getTime()-start90d.getTime();
                chunk90d = chunk90d
                        .add(dayChunk90d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("90天出块量"+chunk90d);
            dto.setLuck90d(chunk90d.divide(dayChunk90d.multiply(BigDecimal.valueOf(90)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            break;
        }while (time < 4);

        redisService.deleteObject("DGBSLuck");
        redisService.setCacheObject("DGBSLuck",dto);
    }

    @Scheduled(cron = "19 1,3,13,31,33,43 * * * ?")
    public void RXD30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("rxd 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.RXD.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.RXD.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.RXD.getFac());
                    }
                });
                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.RXD.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("rxd 构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("rxd user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "rxd 小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "rxd 小时数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("rxd 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.RXD.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.RXD.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.RXD.getFac());
                                }
                            });
                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.RXD.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("rxd 延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("rxd 延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "rxd 30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "rxd 30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "9 1,3,5 0 * * ?")
    public void RXDDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.RXD.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.RXD.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.RXD.getFac());
                    }
                });
                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.RXD.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"rxd 每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"rxd 每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("rxd 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.RXD.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.RXD.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.RXD.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.RXD.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.RXD.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.RXD.getPoolTable() + "_24h", poolPower);
                            System.out.println("rxd 延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "59 0,1,30,31 * * * ?")
    public void RXDUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = poolMapper.getPoolTodayTotalPower("rxd", nowStr);
        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("rxd", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
        });

        if(map.size() >0){
            redisService.deleteObject("RXDUserPowerRatio");
            redisService.setCacheMap("RXDUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "39 2,5 0/12 * * ?")
    public void RXDLuckyDataToDB(){
        log.info("rxd幸运值---定时任务开启");
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        //幸运值 = 矿池实际报块/矿池理论报块
        //矿池实际报块 = 数据库查询表名为币名_pool_blkstats
        //矿池理论报块 =  (矿池过去N段时间的平均算力 / 全网过去N段时间平均算力) * 全网过去N段时间实际报块
        Date start3d = DateUtils.addDays(end,-3);
        Date start7d = DateUtils.addDays(end,-7);
        Date start30d = DateUtils.addDays(end,-30);
        Date start90d = DateUtils.addDays(end,-90);


        //获取全网实际90天内的报块数(v2)
        List<BlockInfoDto> blockPerDays = poolMapper.selectNetBlock("rxd_net_block");
     

        boolean useAggregated = blockPerDays.size() >= 3;
        //获取3天内全网的实际报块数
     
        BlockTimeAndNumberDto blockData = blockDataContext.getBlockData("rxd",start3d, end,blockPerDays, useAggregated);
        //3天矿池理论报块数
        BigDecimal throreticalBlocks= getTheoreticalBlocks("rxd",PoolUnits.RXD.gethRate(),start3d, end, blockData);

        //3天矿池实际报块数
        int actualBlocks = poolMapper.selectPoolBlock(3);
        //3天幸运值
        dto.setLuck3d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //7天幸运值
        useAggregated = blockPerDays.size() >= 7;
     
        blockData = blockDataContext.getBlockData("rxd",start7d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("rxd",PoolUnits.RXD.gethRate(),start7d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(7);
        dto.setLuck7d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        //30天幸运值
        useAggregated = blockPerDays.size() >= 30;
     
        blockData = blockDataContext.getBlockData("rxd",start30d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("rxd",PoolUnits.RXD.gethRate(),start30d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(30);
        dto.setLuck30d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());


        //90天幸运值
        useAggregated = blockPerDays.size() >= 90;
     
        blockData = blockDataContext.getBlockData("rxd",start90d, end,blockPerDays, useAggregated);
        throreticalBlocks= getTheoreticalBlocks("rxd",PoolUnits.RXD.gethRate(),start90d, end, blockData);
        actualBlocks = poolMapper.selectPoolBlock(90);
        dto.setLuck90d(BigDecimal.valueOf(actualBlocks).divide(throreticalBlocks,8, RoundingMode.HALF_UP).doubleValue());

        redisService.deleteObject("RXDLuck");
        redisService.setCacheObject("RXDLuck",dto);
        log.info("rxd幸运值入库完成");
    }

    @Scheduled(cron = "21 1,3,13,31,33,43 * * * ?")
    public void ENX30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("enx 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.ENX.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.ENX.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){

                //list.stream().forEach(e -> {
                //    if(StringUtils.isNotNull(e.getMhs())){
                //        e.setMhs(e.getMhs() * Pools.ENX.getFac());
                //    }
                //});
                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.ENX.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("rxd 构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("rxd user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                Map<String, List<MinerDataDto>> userMap = list.stream().collect(Collectors.groupingBy(MinerDataDto::getMiner));
                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "enx 小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "enx 小时数据存入数据失败");

                }

            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("enx 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.ENX.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.ENX.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            //newList.stream().forEach(e -> {
                            //    if(StringUtils.isNotNull(e.getMhs())){
                            //        e.setMhs(e.getMhs() * Pools.ENX.getFac());
                            //    }
                            //});
                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.ENX.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("enx 延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("enx 延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "enx 30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "enx 30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "10 1,3,5 0 * * ?")
    public void ENXDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.ENX.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.ENX.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){
                //list.stream().forEach(e -> {
                //    if(StringUtils.isNotNull(e.getMhs())){
                //        e.setMhs(e.getMhs() * Pools.ENX.getFac());
                //    }
                //});
                list = filterList(list,now);
                //list.stream().forEach(e ->{
                //    e.setDate(DateUtils.addDays(e.getDate(),-1));
                //});
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.ENX.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"enx 每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"enx 每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("enx 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.ENX.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.ENX.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            //newList.stream().forEach(e -> {
                            //    if(StringUtils.isNotNull(e.getMhs())){
                            //        e.setMhs(e.getMhs() * Pools.ENX.getFac());
                            //    }
                            //});

                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.ENX.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ENX.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            boolean poolResult = poolMapper.insertPoolPower(Pools.ENX.getPoolTable() + "_24h", poolPower);
                            System.out.println("enx 延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "53 0,1,30,31 * * * ?")
    public void ENXUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = poolMapper.getPoolTodayTotalPower("enx", nowStr);
        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("enx", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
        });

        if(map.size() >0){
            redisService.deleteObject("ENXUserPowerRatio");
            redisService.setCacheMap("ENXUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "41 2,5 0/12 * * ?")
    public void ENXLuckyDataToDB(){
        int time = 0;
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        do {
            //幸运值
            // N天应出块数量 = N天矿池平均算力/ N天全网平均算力 * 币种每日出块数 * N天  取同一时间点的矿池算力/全网算力
            // 币种每日出块数 = 720        数值来源: 每日分钟数(24*60) / 出一个块需要的时间(根据具体币种 nexa是2分钟)
            // N天实际出块量 数据库查询N天实际出块量
            // N天幸运值 = N天实际出块量 / N天应出块量 * 100  结果即百分比数字%
            /** 全网每日出块数 */
            BigDecimal rxdCount = PoolCalParamConfig.ENX.getCount();

            //计算矿池每日实际应出块数  block中算力单位是H/s
            int hRate = PoolUnits.ENX.gethRate();
            //先把矿池算力单位转换为H/s 再除以全网算力 得到比值 再乘以每日全网出块数 得到矿池每日应出块数
            List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower("enx");
            if(netPowerList.size() < 1){
                continue;
            }

            List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower("enx");

            //拿报块list 筛选实际出块数
            List<BlockInfoDto> list = poolMapper.getENXBlockInfoList();

            if (list.size() < 1){
                continue;
            }

            //第一条报块数据的时间
            Date poolStart = list.get(list.size() - 1).getDate();
            Date start3d = DateUtils.addDays(end,-3);
            Date start7d = DateUtils.addDays(end,-7);
            Date start30d = DateUtils.addDays(end,-30);
            Date start90d = DateUtils.addDays(end,-90);
            //(矿池平均/全网平均) * (全网计算平均的时间/矿池计算平均的时间) * 每日全网出块数 = 矿池每日应出块数
            long pDay3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            //矿池单位转换
            BigDecimal pPow3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            BigDecimal nPow3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay3d == 0 || nDay3d == 0){
                continue;
            }
            //计算3天 每日出块量
            BigDecimal dayChunk3d = pPow3d
                    .multiply(BigDecimal.valueOf(nDay3d * nDay3d))
                    .divide(nPow3d.multiply(BigDecimal.valueOf(pDay3d * pDay3d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(rxdCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal pPow7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal nPow7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay7d == 0 || nDay7d == 0){
                continue;
            }

            //计算7d 每日应出块量
            BigDecimal dayChunk7d = pPow7d
                    .multiply(BigDecimal.valueOf(nDay7d * nDay7d))
                    .divide(nPow7d.multiply(BigDecimal.valueOf(pDay7d * pDay7d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(rxdCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal pPow30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal nPow30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay30d == 0 || nDay30d == 0){
                continue;
            }

            //计算30d 每日应出块量
            BigDecimal dayChunk30d = pPow30d
                    .multiply(BigDecimal.valueOf(nDay30d * nDay30d))
                    .divide(nPow30d.multiply(BigDecimal.valueOf(pDay30d * pDay30d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(rxdCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal pPow90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal nPow90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay90d == 0 || nDay90d == 0){
                continue;
            }

            //计算90d 每日应出块量
            BigDecimal dayChunk90d = pPow90d
                    .multiply(BigDecimal.valueOf(nDay90d * nDay90d))
                    .divide(nPow90d.multiply(BigDecimal.valueOf(pDay90d * pDay90d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(rxdCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            //3天时间出块数
            long count3d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start3d) || e.getDate().equals(start3d)))
                    .count();
            BigDecimal chunk3d = BigDecimal.valueOf(count3d);
            //7天时间出块数
            long count7d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start7d) || e.getDate().equals(start7d)))
                    .count();
            BigDecimal chunk7d = BigDecimal.valueOf(count7d);
            //30天时间出块数
            long count30d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start30d) || e.getDate().equals(start30d)))
                    .count();
            BigDecimal chunk30d = BigDecimal.valueOf(count30d);
            //90天时间出块数
            long count90d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start90d) || e.getDate().equals(start90d)))
                    .count();
            BigDecimal chunk90d = BigDecimal.valueOf(count90d);

            if(poolStart.after(start3d)){
                System.out.println("不足3天");
                long needTime = poolStart.getTime()-start3d.getTime();
                chunk3d = chunk3d
                        .add(dayChunk3d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("3天出块量"+chunk3d);
            dto.setLuck3d(chunk3d.divide(dayChunk3d.multiply(BigDecimal.valueOf(3)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start7d)){
                System.out.println("不足7天");
                long needTime = poolStart.getTime()-start7d.getTime();
                chunk7d = chunk7d
                        .add(dayChunk7d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("7天出块量"+chunk7d);
            dto.setLuck7d(chunk7d.divide(dayChunk7d.multiply(BigDecimal.valueOf(7)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());


            if(poolStart.after(start30d)){
                System.out.println("不足30天");
                long needTime = poolStart.getTime()-start30d.getTime();
                chunk30d = chunk30d
                        .add(dayChunk30d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("30天出块量"+chunk30d);
            dto.setLuck30d(chunk30d.divide(dayChunk30d.multiply(BigDecimal.valueOf(30)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start90d)){
                System.out.println("不足90天");
                long needTime = poolStart.getTime()-start90d.getTime();
                chunk90d = chunk90d
                        .add(dayChunk90d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("90天出块量"+chunk90d);
            dto.setLuck90d(chunk90d.divide(dayChunk90d.multiply(BigDecimal.valueOf(90)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            break;
        }while (time < 4);

        redisService.deleteObject("ENXLuck");
        redisService.setCacheObject("ENXLuck",dto);
    }

    @Scheduled(cron = "23 1,3,13,31,33,43 * * * ?")
    public void ALPH30mDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        int minute = (now.getMinutes() / 30) * 30;
        now.setMinutes( minute);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        System.out.println("alph 30分钟定时任务执行时间:"+now);
        System.out.println("格式化后的时间:"+nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.ALPH.getMhs() + "30m", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getHourMinerDataList(Pools.ALPH.getMhs()+"_realv2",nowStr);
            if(list.size() > 0){
                List<MinerDataDto> offlineList = new ArrayList<>();
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.ALPH.getFac());
                    }
                    if("offline".equals(e.getState())){
                        offlineList.add(e);
                    }
                });
                list = filterList(list,now);

                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.ALPH.getMhs() + "30m", getToHourDBListByMinerDataList(list));

                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_30m", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_30m", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    System.out.println("构造写入user算力表数据");
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );
                    System.out.println("user算力表入库数据条数："+userList.size());
                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_30m", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_30m", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });

                if (result) {
                    System.out.println(DateUtils.dateTimeNow() + "alph小时数据存入数据成功");
                } else {
                    System.out.println(DateUtils.dateTimeNow() + "alph小时数据存入数据失败");
                }
            }
            else{
                //重来一次！
                CompletableFuture.runAsync(()->{
                    System.out.println("alph 30分钟定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.ALPH.getMhs() + "30m", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getHourMinerDataList(Pools.ALPH.getMhs()+"_realv2",nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.ALPH.getFac());
                                }
                            });
                            newList = filterList(newList,now);

                            boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.ALPH.getMhs() + "30m", getToHourDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_30m", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_30m", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                System.out.println("延迟任务 构造写入user算力表数据");
                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );
                                System.out.println("延迟任务 user算力表入库数据条数："+userList.size());
                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_30m", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_30m", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });
                            if (newResult) {
                                System.out.println(DateUtils.dateTimeNow() + "alph30m数据 延迟存入数据成功");
                            } else {
                                System.out.println(DateUtils.dateTimeNow() + "alph30m数据 延迟存入数据失败");

                            }

                        }
                    }
                });

            }
        }

    }

    @Scheduled(cron = "12 1,3,5 0 * * ?")
    public void ALPHDailyDataToDB(){
        String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
        Date now = DateUtils.parseDate( nowStr);

        //检查二级表是否有当前时间数据
        int count = poolMapper.getLastDataTime(Pools.ALPH.getMhs() + "24h", nowStr);

        if(count == 0) {
            List<MinerDataDto> list = poolMapper.getDailyMinerDataList(Pools.ALPH.getMhs()+"_realv2", nowStr);
            if(list.size() > 0){
                list.stream().forEach(e -> {
                    if(StringUtils.isNotNull(e.getMhs())){
                        e.setMhs(e.getMhs() * Pools.ALPH.getFac());
                    }
                });
                list = filterList(list,now);
                boolean result = poolMapper.batchInsertMhsDataToDB(Pools.ALPH.getMhs() + "24h", getToDailyDBListByMinerDataList(list));
                //todo 统计矿池数据写入矿池数据库 $coin_pool_24h
                Map<Date, List<MinerDataDto>> map = list.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                map.forEach((date,dList) -> {
                    PoolPower poolPower  = new PoolPower();
                    //poolPower.setDate(date);
                    poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                    Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                    poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                    poolPower.setMiners(dList.size());
                    poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                    poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                    boolean poolResult = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_24h", poolPower);
                    int time =0;
                    while (!poolResult){
                        poolResult = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_24h", poolPower);
                        if (time > 5) {
                            break;
                        }
                        time ++;
                    }

                    //写入数据到coin_users表中
                    Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                    List<MinerDataInsertDBDto> userList = new ArrayList<>();
                    userMap.forEach((user,uList)->{
                        MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                        uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                        uDto.setUser(user);
                        uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                        userList.add(uDto);
                    } );

                    boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_24h", userList);
                    int uTime =0;
                    while (!userResult){
                        userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_24h", userList);
                        if (uTime > 5) {
                            break;
                        }
                        uTime ++;
                    }
                });
                if(result){
                    System.out.println(DateUtils.dateTimeNow()+"alph每日存入数据成功");
                }else {
                    System.out.println(DateUtils.dateTimeNow()+"alph每日存入数据失败");

                }

            }else {
                CompletableFuture.runAsync(()->{
                    System.out.println("alph 每日矿池定时任务执行失败 延时一分钟时间重新查询");
                    System.out.println("延迟后使用的查询时间:"+now);
                    System.out.println("延迟后 格式化后的时间:"+nowStr);

                    //检查二级表是否有当前时间数据
                    int newCount = poolMapper.getLastDataTime(Pools.ALPH.getMhs() + "24h", nowStr);
                    if(newCount == 0){
                        List<MinerDataDto> newList = poolMapper.getDailyMinerDataList(Pools.ALPH.getMhs()+"_realv2", nowStr);
                        if(newList.size() > 0){

                            newList.stream().forEach(e -> {
                                if(StringUtils.isNotNull(e.getMhs())){
                                    e.setMhs(e.getMhs() * Pools.ALPH.getFac());
                                }
                            });

                            newList = filterList(newList,now);

                            //boolean newResult = poolMapper.batchInsertMhsDataToDB(Pools.ALPH.getMhs() + "24h", getToDailyDBListByMinerDataList(newList));

                            Map<Date, List<MinerDataDto>> map2 = newList.stream().collect(Collectors.groupingBy(MinerDataDto::getDate));
                            map2.forEach((date,dList) -> {
                                PoolPower poolPower  = new PoolPower();
                                //poolPower.setDate(date);
                                poolPower.setDateStr(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                Map<String, Long> stateCount = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getState, Collectors.counting()));
                                poolPower.setMhs(dList.stream().map(e -> BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().stripTrailingZeros());
                                poolPower.setMiners(dList.size());
                                poolPower.setOnline(Convert.toInt(stateCount.get("online"),0));
                                poolPower.setOffline(Convert.toInt(stateCount.get("offline"),0));

                                boolean poolResult2 = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_24h", poolPower);
                                int time =0;
                                while (!poolResult2){
                                    poolResult2 = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_24h", poolPower);
                                    if (time > 5) {
                                        break;
                                    }
                                    time ++;
                                }

                                Map<String, List<MinerDataDto>> userMap = dList.stream().collect(Collectors.groupingBy(MinerDataDto::getUser));
                                List<MinerDataInsertDBDto> userList = new ArrayList<>();
                                userMap.forEach((user,uList)->{
                                    MinerDataInsertDBDto uDto = new MinerDataInsertDBDto();
                                    uDto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,date));
                                    uDto.setUser(user);
                                    uDto.setMhs(uList.stream().map(e->BigDecimal.valueOf(e.getMhs())).reduce(BigDecimal::add).get().doubleValue());
                                    userList.add(uDto);
                                } );

                                boolean userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_24h", userList);
                                int uTime =0;
                                while (!userResult){
                                    userResult = poolMapper.batchInsertUserMhsDateToDB(Pools.ALPH.getCoin() + "_users_24h", userList);
                                    if (uTime > 5) {
                                        break;
                                    }
                                    uTime ++;
                                }
                            });


                        }else {
                            PoolPower poolPower  = new PoolPower();
                            poolPower.setDate(now);
                            poolPower.setMhs(BigDecimal.ZERO);
                            poolPower.setMiners(0);
                            poolPower.setOnline(0);
                            poolPower.setOffline(0);
                            //boolean poolResult = poolMapper.insertPoolPower(Pools.ALPH.getPoolTable() + "_24h", poolPower);
                            System.out.println("延时任务未查到 构造0数据入库,结果:"+poolPower);
                        }
                    }
                });
            }
        }
    }

    @Scheduled(cron = "52 0,1,30,31 * * * ?")
    public void ALPHUserPowerRatioDataToDB(){
        //String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:mm:00");

        Date now = new Date();
        now.setHours(0);
        now.setMinutes(0);
        now.setSeconds(0);
        String nowStr = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, now);

        BigDecimal poolMhs = poolMapper.getPoolTodayTotalPower("alph", nowStr);
        List<UserPowerDto> userMhsList = poolMapper.getUserTodayTotalPower("alph", nowStr);
        HashMap<String,BigDecimal> map = new HashMap<>();
        userMhsList.stream().forEach(e ->{
            map.put(e.getUser(),e.getMhs().divide(poolMhs,8,BigDecimal.ROUND_HALF_UP));
        });

        if(map.size() >0){
            redisService.deleteObject("ALPHUserPowerRatio");
            redisService.setCacheMap("ALPHUserPowerRatio",map);
        }

    }

    //@Scheduled(cron = "30 2,7 0,12 * * ?")
    @Scheduled(cron = "42 2,5 0/12 * * ?")
    public void ALPHLuckyDataToDB(){
        int time = 0;
        LuckDto dto = new LuckDto();
        Date end =  DateUtils.parseDate(DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD));
        do {
            //幸运值
            // N天应出块数量 = N天矿池平均算力/ N天全网平均算力 * 币种每日出块数 * N天  取同一时间点的矿池算力/全网算力
            // 币种每日出块数 = 720        数值来源: 每日分钟数(24*60) / 出一个块需要的时间(根据具体币种 nexa是2分钟)
            // N天实际出块量 数据库查询N天实际出块量
            // N天幸运值 = N天实际出块量 / N天应出块量 * 100  结果即百分比数字%
            /** 全网每日出块数 */
            BigDecimal nexaCount = PoolCalParamConfig.ALPH.getCount();

            //计算矿池每日实际应出块数  block中算力单位是H/s
            int hRate = PoolUnits.ALPH.gethRate();
            //先把矿池算力单位转换为H/s 再除以全网算力 得到比值 再乘以每日全网出块数 得到矿池每日应出块数
            List<DateBigDecimalDto> netPowerList = poolMapper.getDailyNetPower("alph");
            if(netPowerList.size() < 1){
                continue;
            }

            List<DateBigDecimalDto> poolPowerList = poolMapper.getDailyPoolPower("alph");

            //拿报块list 筛选实际出块数
            List<BlockInfoDto> list = poolMapper.getNEXABlockInfoList();

            if (list.size() < 1){
                continue;
            }

            //第一条报块数据的时间
            Date poolStart = list.get(list.size() - 1).getDate();
            Date start3d = DateUtils.addDays(end,-3);
            Date start7d = DateUtils.addDays(end,-7);
            Date start30d = DateUtils.addDays(end,-30);
            Date start90d = DateUtils.addDays(end,-90);
            //(矿池平均/全网平均) * (全网计算平均的时间/矿池计算平均的时间) * 每日全网出块数 = 矿池每日应出块数
            long pDay3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            //矿池单位转换
            BigDecimal pPow3d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d))).count();

            BigDecimal nPow3d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start3d) || e.getPDate().equals(start3d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay3d == 0 || nDay3d == 0){
                continue;
            }
            //计算3天 每日出块量
            BigDecimal dayChunk3d = pPow3d
                    .multiply(BigDecimal.valueOf(nDay3d * nDay3d))
                    .divide(nPow3d.multiply(BigDecimal.valueOf(pDay3d * pDay3d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal pPow7d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d))).count();

            BigDecimal nPow7d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start7d) || e.getPDate().equals(start7d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay7d == 0 || nDay7d == 0){
                continue;
            }

            //计算7d 每日应出块量
            BigDecimal dayChunk7d = pPow7d
                    .multiply(BigDecimal.valueOf(nDay7d * nDay7d))
                    .divide(nPow7d.multiply(BigDecimal.valueOf(pDay7d * pDay7d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal pPow30d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d))).count();

            BigDecimal nPow30d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start30d) || e.getPDate().equals(start30d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay30d == 0 || nDay30d == 0){
                continue;
            }

            //计算30d 每日应出块量
            BigDecimal dayChunk30d = pPow30d
                    .multiply(BigDecimal.valueOf(nDay30d * nDay30d))
                    .divide(nPow30d.multiply(BigDecimal.valueOf(pDay30d * pDay30d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            long pDay90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal pPow90d = poolPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add)
                    .multiply(BigDecimal.valueOf(hRate));

            long nDay90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d))).count();

            BigDecimal nPow90d = netPowerList.stream()
                    .filter(e -> (e.getPDate().before(end)))
                    .filter(e -> (e.getPDate().after(start90d) || e.getPDate().equals(start90d)))
                    .map(e -> e.getValue()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if(pDay90d == 0 || nDay90d == 0){
                continue;
            }

            //计算90d 每日应出块量
            BigDecimal dayChunk90d = pPow90d
                    .multiply(BigDecimal.valueOf(nDay90d * nDay90d))
                    .divide(nPow90d.multiply(BigDecimal.valueOf(pDay90d * pDay90d)),8,BigDecimal.ROUND_HALF_UP)
                    .multiply(nexaCount)
                    .setScale(8, BigDecimal.ROUND_HALF_UP);

            //3天时间出块数
            long count3d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start3d) || e.getDate().equals(start3d)))
                    .count();
            BigDecimal chunk3d = BigDecimal.valueOf(count3d);
            //7天时间出块数
            long count7d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start7d) || e.getDate().equals(start7d)))
                    .count();
            BigDecimal chunk7d = BigDecimal.valueOf(count7d);
            //30天时间出块数
            long count30d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start30d) || e.getDate().equals(start30d)))
                    .count();
            BigDecimal chunk30d = BigDecimal.valueOf(count30d);
            //90天时间出块数
            long count90d = list.stream()
                    .filter(e -> (e.getDate().before(end)))
                    .filter(e -> (e.getDate().after(start90d) || e.getDate().equals(start90d)))
                    .count();
            BigDecimal chunk90d = BigDecimal.valueOf(count90d);

            if(poolStart.after(start3d)){
                System.out.println("不足3天");
                long needTime = poolStart.getTime()-start3d.getTime();
                chunk3d = chunk3d
                        .add(dayChunk3d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("3天出块量"+chunk3d);
            dto.setLuck3d(chunk3d.divide(dayChunk3d.multiply(BigDecimal.valueOf(3)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start7d)){
                System.out.println("不足7天");
                long needTime = poolStart.getTime()-start7d.getTime();
                chunk7d = chunk7d
                        .add(dayChunk7d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("7天出块量"+chunk7d);
            dto.setLuck7d(chunk7d.divide(dayChunk7d.multiply(BigDecimal.valueOf(7)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());


            if(poolStart.after(start30d)){
                System.out.println("不足30天");
                long needTime = poolStart.getTime()-start30d.getTime();
                chunk30d = chunk30d
                        .add(dayChunk30d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("30天出块量"+chunk30d);
            dto.setLuck30d(chunk30d.divide(dayChunk30d.multiply(BigDecimal.valueOf(30)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            if(poolStart.after(start90d)){
                System.out.println("不足90天");
                long needTime = poolStart.getTime()-start90d.getTime();
                chunk90d = chunk90d
                        .add(dayChunk90d.multiply(BigDecimal.valueOf(needTime).divide(BigDecimal.valueOf(86400000),8,BigDecimal.ROUND_HALF_UP)));
            }
            System.out.println("90天出块量"+chunk90d);
            dto.setLuck90d(chunk90d.divide(dayChunk90d.multiply(BigDecimal.valueOf(90)),4,BigDecimal.ROUND_HALF_UP).multiply(BigDecimal.valueOf(100)).doubleValue());

            break;
        }while (time < 4);

        redisService.deleteObject("ALPHLuck");
        redisService.setCacheObject("ALPHLuck",dto);
    }

    //@Scheduled(cron = "5 2,4,6 0/1 * * ?")
    //public void NEXAHourUserDataToDB(){
    //    String nowStr = DateUtils.dateTimeNow("yyyy-MM-dd HH:00:00");
    //    Date now = DateUtils.parseDate( nowStr);
    //
    //    System.out.println("执行时间:"+now);
    //
    //    //检查二级表是否有当前时间数据
    //    int count = poolMapper.getLastDataTime(Pools.NEXA.getCoin() + "_users" +"_1h", nowStr);
    //
    //    if(count == 0) {
    //        List<MinerDataDto> list = poolMapper.getUserHourMinerDataList(Pools.NEXA.getCoin() + "_users" +"_stats");
    //
    //        if(list.size() > 0){
    //            //处理list 1、根据时间筛选 2、根据状态筛选 3、数据时间格式化'
    //            list = filterList(list,now);
    //
    //            boolean result = poolMapper.batchInsertUserMhsDataToDB(Pools.NEXA.getCoin() + "_users" + "_1h", getToHourDBListByMinerDataList(list));
    //            if (result) {
    //                System.out.println(DateUtils.dateTimeNow() + "nexa小时数据存入数据成功");
    //            } else {
    //                System.out.println(DateUtils.dateTimeNow() + "nexa小时数据存入数据失败");
    //
    //            }
    //
    //        }
    //    }
    //
    //}
    //
    //@Scheduled(cron = "0 2,3,4 0 * * ?")
    //public void NEXADailyUserDataToDB(){
    //    String nowStr = DateUtils.dateTimeNow(DateUtils.YYYY_MM_DD);
    //    Date now = DateUtils.parseDate( nowStr);
    //    //检查二级表是否有当前时间数据
    //    int count = poolMapper.getLastDataTime(Pools.NEXA.getCoin() + "_users" + "_1d", nowStr);
    //
    //    if(count == 0) {
    //        List<MinerDataDto> list = poolMapper.getUserDailyMinerDataList(Pools.NEXA.getCoin() + "_users" + "_stats");
    //        if(list.size() > 0){
    //
    //            list = filterList(list,now);
    //
    //            list.stream().forEach(e ->{
    //                e.setDate(DateUtils.addDays(e.getDate(),-1));
    //            });
    //
    //            boolean result = poolMapper.batchInsertUserMhsDataToDB(Pools.NEXA.getCoin() + "_users" + "_1d", getToDailyDBListByMinerDataList(list));
    //            if(result){
    //                System.out.println(DateUtils.dateTimeNow()+"nexa用户每日统计存入数据成功");
    //            }else {
    //                System.out.println(DateUtils.dateTimeNow()+"nexa用户每日统计存入数据失败");
    //
    //            }
    //
    //        }
    //    }
    //}

    /**
     * 格式化list中对象的日期
     * @param list
     * @return
     */
    public static List<MinerDataInsertDBDto> getToHourDBListByMinerDataList(List<MinerDataDto> list){
        List<MinerDataInsertDBDto> dbList = list.stream().map(e -> {
            MinerDataInsertDBDto dto = new MinerDataInsertDBDto();
            BeanUtils.copyProperties(e, dto);
            dto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,e.getDate()));
            if(StringUtils.isNotNull(e.getLastSubmit())){
                dto.setLastSubmit(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,e.getLastSubmit()));
            }
            return dto;
        }).collect(Collectors.toList());

        return dbList;
    }

    /**
     *格式化对象 日期属性为YYYY_MM_DD
     * @param list
     * @return
     */
    public static List<MinerDataInsertDBDto> getToDailyDBListByMinerDataList(List<MinerDataDto> list){
        List<MinerDataInsertDBDto> dbList = list.stream().map(e -> {
            MinerDataInsertDBDto dto = new MinerDataInsertDBDto();
            BeanUtils.copyProperties(e, dto);
            dto.setDate(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD,e.getDate()));
            if(StringUtils.isNotNull(e.getLastSubmit())){
                dto.setLastSubmit(DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,e.getLastSubmit()));
            }
            return dto;
        }).collect(Collectors.toList());

        return dbList;
    }

    /**
     * 过滤重复数据
     * @param list
     * @param now
     * @return
     */
    public static List<MinerDataDto> filterList(List<MinerDataDto> list,Date now){

        if(list.size()<1){
            return list;
        }

        list = list.stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(o -> o.getUser() + ":" + o.getMiner()))), ArrayList::new));

        //list user:miner 重复拿date最新的数据
        list = list.stream().
                collect(Collectors.toMap(
                        e -> e.getUser()+":"+ e.getMiner(),
                        Function.identity(),
                        (p1,p2) -> p1.getDate().after(p2.getDate()) ? p1 : p2)).values().stream().collect(Collectors.toList());

        list.stream().forEach(e ->{
            if (!DateUtils.isSameDate(e.getDate(),now)){
                System.out.println(e.getDate().getTime()+" before "+now.getTime());
                e.setAccepts(0);
                e.setRejects(0);
                e.setRejectsRatio(0);
                e.setMhs(0);
                e.setMhs24h(0);
            }

            e.setDate(now);

        });

        return list;
    }

}
